Abacus.AI API Python API Client [![PyPI version](https://badge.fury.io/py/abacusai.svg)](https://badge.fury.io/py/abacusai)
============

The official Python API Client Library for Abacus.AI.

## Install

```console
$ pip install abacusai
```

## Getting Started

### Calling an API

To call an API, you must first instantiate an `ApiClient`.

```python
from abacusai import ApiClient
client = ApiClient('YOUR_API_KEY')
```

You can find your API key from here: [API KEY](https://abacus.ai/app/profile/apikey)

## Documentation

- Python SDK Documentation: [Abacus.AI Python SDK](https://abacusai.github.io/api-python/autoapi/abacusai/index.html)
- Full list of API's and examples: [Abacus.AI APIs Reference](https://abacus.ai/app/help/ref/overview)
- Python usage examples: [Examples Repository](https://github.com/abacusai/api-python/blob/main/examples)

## License
[MIT](https://github.com/abacusai/api-python/blob/main/LICENSE)
